==> mongodb-src-r5.0.15.tar.gz: mongodb-src-r5.0.15/src/mongo/db/process_health/fault_facet_impl.h <==
/**
 *    Copyright (C) 2021-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */
#pragma once

#include "mongo/db/process_health/fault_facet.h"

#include "mongo/db/process_health/health_check_status.h"
#include "mongo/db/process_health/health_observer.h"
#include "mongo/util/clock_source.h"

namespace mongo {
namespace process_health {

// Internal representation of the Facet.
class FaultFacetImpl : public FaultFacet {
public:
    FaultFacetImpl(FaultFacetType type, ClockSource* clockSource, HealthCheckStatus status);

    ~FaultFacetImpl() override = default;

    // Public interface methods.

    FaultFacetType getType() const override;

    HealthCheckStatus getStatus() const override;

    Milliseconds getDuration() const override;

    void update(HealthCheckStatus status) override;

    void appendDescription(BSONObjBuilder* builder) const override;

private:
    const FaultFacetType _type;
    ClockSource* const _clockSource;

    const Date_t _startTime = _clockSource->now();

    mutable Mutex _mutex =
        MONGO_MAKE_LATCH(HierarchicalAcquisitionLevel(1), "FaultFacetImpl::_mutex");
    Severity _severity = Severity::kOk;
    std::string _description;
};

}  // namespace process_health
}  // namespace mongo

==> mongodb-src-r5.2.0.tar.gz: mongodb-src-r5.2.0/src/mongo/db/process_health/fault_facet_impl.h <==
/**
 *    Copyright (C) 2021-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */
#pragma once

#include "mongo/db/process_health/fault_facet.h"

#include "mongo/db/process_health/health_check_status.h"
#include "mongo/db/process_health/health_observer.h"
#include "mongo/util/clock_source.h"

namespace mongo {
namespace process_health {

// Internal representation of the Facet.
class FaultFacetImpl : public FaultFacet {
public:
    FaultFacetImpl(FaultFacetType type, ClockSource* clockSource, HealthCheckStatus status);

    ~FaultFacetImpl() override = default;

    // Public interface methods.

    FaultFacetType getType() const override;

    HealthCheckStatus getStatus() const override;

    void update(HealthCheckStatus status) override;

private:
    const FaultFacetType _type;
    ClockSource* const _clockSource;

    const Date_t _startTime = _clockSource->now();

    mutable Mutex _mutex =
        MONGO_MAKE_LATCH(HierarchicalAcquisitionLevel(1), "FaultFacetImpl::_mutex");
    double _severity = 0;
    std::string _description;
};

}  // namespace process_health
}  // namespace mongo
